@@ -6,7 +6,9 @@ sys.path.append(str(pathlib.Path(__file__).resolve().parents[1] / "src"))
 
 from typer.testing import CliRunner
 
-from proxy2vpn import cli, docker_ops
+from proxy2vpn.cli.main import app
+from proxy2vpn.adapters import docker_ops
+from proxy2vpn.adapters import compose_manager
 
 
 def test_vpn_restart_all_recreates(monkeypatch):
@@ -20,7 +22,12 @@ def test_vpn_restart_all_recreates(monkeypatch):
         get_service=lambda name: SimpleNamespace(name=name, profile="prof1"),
     )
 
-    monkeypatch.setattr(cli, "ComposeManager", lambda path: dummy_mgr)
+    def mock_compose_manager_from_ctx(ctx):
+        return dummy_mgr
+
+    monkeypatch.setattr(
+        compose_manager.ComposeManager, "from_ctx", mock_compose_manager_from_ctx
+    )
 
     calls = []
 
@@ -33,7 +40,7 @@ def test_vpn_restart_all_recreates(monkeypatch):
     monkeypatch.setattr(docker_ops, "recreate_vpn_container", fake_recreate)
     monkeypatch.setattr(docker_ops, "start_container", fake_start)
 
-    result = runner.invoke(cli.app, ["vpn", "restart", "--all"])
+    result = runner.invoke(app, ["vpn", "restart", "--all"])
     assert result.exit_code == 0
     assert "Recreated and restarted svc1" in result.stdout
     assert ("recreate", "svc1") in calls
